@@ -210,7 +210,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	xmlNodePtr     child;
 	gchar          *name;
 	gint           id;
-	mrptime        start, end;
+	mrptime        start = 0, end = 0;
 	MrpTask       *task;
 	MrpConstraint  constraint;
 	guint          percent_complete = 0;
@@ -273,6 +273,11 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 			duration = work;
 		}
 
+		if (type == MRP_TASK_TYPE_MILESTONE) {
+			work = 0;
+			duration = 0;
+		}
+		
 		task = g_object_new (MRP_TYPE_TASK,
 				     "project", parser->project,
 				     "name", name,
@@ -301,7 +306,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 
 		work = mrp_project_calculate_task_work (parser->project,
 							task,
-							duration);
+							start, end);
 		
 		g_object_set (task,
 			      "work", work,
@@ -541,7 +546,7 @@ old_xml_read_overridden_day_type (MrpParser   *parser,
 {
 	gint        id;
 	MrpDay     *mrp_day;
-	GSList     *intervals = NULL;
+	GList      *intervals = NULL;
 	xmlNodePtr  child;
 
 	if (strcmp (day->name, "overridden-day-type") != 0){
@@ -573,14 +578,14 @@ old_xml_read_overridden_day_type (MrpParser   *parser,
 			end = hour * 60 * 60 + min * 60;
 
 			interval = mrp_interval_new (start, end);
-			intervals = g_slist_append (intervals, interval);
+			intervals = g_list_append (intervals, interval);
 		}
 	}
 
 	mrp_calendar_day_set_intervals (calendar, mrp_day, intervals);
 	
-	g_slist_foreach (intervals, (GFunc) mrp_interval_unref, NULL);
-	g_slist_free (intervals);
+	g_list_foreach (intervals, (GFunc) mrp_interval_unref, NULL);
+	g_list_free (intervals);
 }
 
 static void 
@@ -1012,7 +1017,7 @@ old_xml_read_project (MrpParser *parser)
 			old_xml_read_group (parser, groups); 
 		}
 	}
-
+	
 	gid = old_xml_get_int (child, "default_group");
         parser->default_group = g_hash_table_lookup (parser->group_hash,
 						     GINT_TO_POINTER (gid));
@@ -1219,16 +1224,16 @@ old_xml_get_task_sched (xmlNodePtr node, const char *name)
 
 	val = old_xml_get_value (node, name);
 	if (val == NULL) {
-		return MRP_TASK_SCHED_NORMAL;
+		return MRP_TASK_SCHED_FIXED_WORK;
 	}
 
 	if (!strcmp (val, "fixed-duration")) {
-		sched = MRP_TASK_SCHED_VAR_EFFORT;
+		sched = MRP_TASK_SCHED_FIXED_DURATION;
 	}
 	else if (!strcmp (val, "fixed-work")) {
-		sched = MRP_TASK_SCHED_NORMAL;
+		sched = MRP_TASK_SCHED_FIXED_WORK;
 	} else {
-		sched = MRP_TASK_SCHED_NORMAL;
+		sched = MRP_TASK_SCHED_FIXED_WORK;
 	}
        
 	xmlFree (val);
@@ -1326,15 +1331,15 @@ old_xml_set_property_from_node (MrpProject *project,
 
 	str = old_xml_get_string (node, "value");
 
-	property = imrp_project_get_property (project,
-					      name,
-					      G_OBJECT_TYPE (object));
+	property = mrp_project_get_property (project,
+					     name,
+					     G_OBJECT_TYPE (object));
 
 	if (property == NULL) {
 		return;
 	}
 	
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
@@ -1441,7 +1446,7 @@ mrp_old_xml_parse (MrpProject *project, xmlDoc *doc, GError **error)
 		return FALSE;
 	}
 	
-        task_manager = mrp_project_get_task_manager (project);
+        task_manager = imrp_project_get_task_manager (project);
         mrp_task_manager_set_root (task_manager, parser.root_task);
 
 	g_object_set (project,
@@ -1457,15 +1462,15 @@ mrp_old_xml_parse (MrpProject *project, xmlDoc *doc, GError **error)
         g_hash_table_destroy (parser.task_hash);
 	g_list_free (parser.delayed_relations);
 
-       	mrp_project_set_groups (project, parser.groups);
+       	imrp_project_set_groups (project, parser.groups);
 
        	for (node = parser.assignments; node; node = node->next) {
 		assignment = MRP_ASSIGNMENT (node->data);
 
-		mrp_task_add_assignment (mrp_assignment_get_task (assignment),
-					 assignment);
-		mrp_resource_add_assignment (mrp_assignment_get_resource (assignment),
-					     assignment);
+		imrp_task_add_assignment (mrp_assignment_get_task (assignment),
+					  assignment);
+		imrp_resource_add_assignment (mrp_assignment_get_resource (assignment),
+					      assignment);
 		g_object_unref (assignment);
 	}
 
