@@ -52,7 +52,7 @@ struct _MrpCalendarPriv {
 	
 	/* Tree structure */
 	MrpCalendar *parent;
-	GSList      *children;
+	GList      *children;
 	
 	/* Working time intervals set for day types in this calendar */
 	GHashTable  *day_intervals;
@@ -94,7 +94,7 @@ static void        calendar_add_child            (MrpCalendar      *parent,
 static void        calendar_reparent             (MrpCalendar      *new_parent,
 						  MrpCalendar      *child);
 static void        calendar_emit_changed         (MrpCalendar      *calendar);
-static GSList *    calendar_clean_intervals      (GSList           *list);
+static GList *    calendar_clean_intervals      (GList           *list);
 
 
 static MrpObjectClass *parent_class;
@@ -150,16 +150,16 @@ calendar_class_init (MrpCalendarClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_NAME,
 					 g_param_spec_string ("name",
-							      "Calendar Name",
-							      NULL,
+							      "Name",
+							      "The name of the calendar",
 							      "empty",
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_PROJECT,
 					 g_param_spec_pointer ("project",
-							       "Project name is attached to",
-							       NULL,
+							       "Project",
+							       "The project this calendar belongs to",
 							       G_PARAM_READWRITE));
 
 	imrp_day_setup_defaults ();
@@ -324,7 +324,7 @@ calendar_add_child (MrpCalendar *parent, MrpCalendar *child)
 		return;
 	}
 
-	parent->priv->children = g_slist_prepend (parent->priv->children, 
+	parent->priv->children = g_list_prepend (parent->priv->children, 
 						  g_object_ref (child));
 	
 	child->priv->parent = parent;
@@ -337,7 +337,7 @@ calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 		MrpCalendar *parent;
 
 		parent = child->priv->parent;
-		parent->priv->children = g_slist_remove (parent->priv->children,
+		parent->priv->children = g_list_remove (parent->priv->children,
 							 child);
 		child->priv->parent = NULL;
 	}
@@ -348,12 +348,14 @@ calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 
 /**
  * mrp_calendar_new:
- * @name: Name of the calendar
+ * @name: name of the calendar
+ * @project: the #MrpProject that the new calendar will belong to
  * 
- * Creates a new #MrpCalendar. The calendar will be empty so you would have 
- * to set default days on it.
- * 
- * Return value: a new #MrpCalendar
+ * Creates a new #MrpCalendar. The calendar will be empty so you need to set the
+ * default week and/or override days, see mrp_calendar_set_default_days() and
+ * mrp_calendar_set_days().
+ *
+ * Return value: A new #MrpCalendar.
  **/
 MrpCalendar *
 mrp_calendar_new (const gchar *name, MrpProject *project)
@@ -374,10 +376,10 @@ foreach_copy_day_intervals (gpointer     key,
 			    MrpCalendar *copy)
 {
 	MrpDay *day = key;
-	GSList *list;
+	GList *list;
 
-	list = g_slist_copy (value);
-	g_slist_foreach (list, (GFunc) mrp_interval_ref, NULL);
+	list = g_list_copy (value);
+	g_list_foreach (list, (GFunc) mrp_interval_ref, NULL);
 
 	g_hash_table_insert (copy->priv->day_intervals, day, list);
 }
@@ -394,11 +396,11 @@ foreach_copy_days (gpointer     key,
 
 /**
  * mrp_calendar_copy:
- * @name: Name of the new calendar
+ * @name: the name of the new calendar
  * @calendar: a #MrpCalendar to copy
  * 
- * Copies @calendar, the copy will be a base calendar and will not have 
- * any parents.
+ * Copies @calendar, making the new calendar a base calendar, that does not have
+ * a parent.
  * 
  * Return value: a new #MrpCalendar that is a copy of @calendar.
  **/
@@ -431,12 +433,14 @@ mrp_calendar_copy (const gchar *name, MrpCalendar *calendar)
 
 /**
  * mrp_calendar_derive:
- * @name: Name of the new calendar
+ * @name: the name of the new calendar
  * @parent: the #MrpCalendar to derive
  * 
- * Derives @parent so that specific days can be overridden.
+ * Derives a new calendar from @parent. The new calendar will inherit all
+ * properties from @parent, so if no days are overridden, the calendars will be
+ * identical.
  * 
- * Return value: a new #MrpCalendar that overrides @parent.
+ * Return value: a new #MrpCalendar that is derived from @parent.
  **/
 MrpCalendar *
 mrp_calendar_derive (const gchar *name, MrpCalendar *parent)
@@ -458,6 +462,15 @@ mrp_calendar_derive (const gchar *name, MrpCalendar *parent)
 	return ret_val;
 }
 
+/**
+ * mrp_calendar_reparent:
+ * @new_parent: the new parent
+ * @child: an #MrpCalendar
+ *
+ * Changes the parent of @calendar so that it inherits @new_parent, instead of
+ * its old parent.
+ * 
+ **/
 void
 mrp_calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 {
@@ -470,13 +483,24 @@ mrp_calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 	imrp_project_set_needs_saving (new_parent->priv->project, TRUE);
 }
 
+/**
+ * mrp_calendar_remove:
+ * @calendar: an #MrpCalendar
+ * 
+ * Removes @calendar from the project. If the calendar is used by the project, a
+ * new calendar is set for the project. If the calendar has a parent, the parent
+ * is used, otherwise the first child of the root is used. For resources, the
+ * calendar is exchanged for the parent if one exists, otherwise the resource
+ * calendar is unset, so that the project default will be used.
+ * 
+ **/
 void
 mrp_calendar_remove (MrpCalendar *calendar)
 {
 	MrpCalendarPriv *priv;
 	MrpCalendar     *parent;
 	MrpCalendar     *root;
-	GSList          *list, *l;
+	GList          *list, *l;
 	GList           *resources, *r;
 	MrpCalendar     *tmp_cal, *new_cal = NULL;
 
@@ -532,7 +556,6 @@ mrp_calendar_remove (MrpCalendar *calendar)
 			mrp_resource_set_calendar (resource, new_cal);
 		}
 	}
-	g_list_free (resources);
 	
 	/* FIXME: Need to check tasks when/if they get calendar
 	 * support. Do it like for the resources.
@@ -543,7 +566,7 @@ mrp_calendar_remove (MrpCalendar *calendar)
 	 * changed in calendar_reparent. Prevents corrupt list with infinite
 	 * loops etc.
 	 */
-	list = g_slist_copy (priv->children);
+	list = g_list_copy (priv->children);
 	
 	for (l = list; l; l = l->next) {
 		MrpCalendar *child = l->data;
@@ -557,10 +580,10 @@ mrp_calendar_remove (MrpCalendar *calendar)
 		}
 	}
 
-	g_slist_free (list);
+	g_list_free (list);
 	
 	if (parent) {
-		parent->priv->children = g_slist_remove (parent->priv->children,
+		parent->priv->children = g_list_remove (parent->priv->children,
 							 calendar);
 		priv->parent = NULL;
 	}
@@ -571,6 +594,14 @@ mrp_calendar_remove (MrpCalendar *calendar)
 	g_object_unref (calendar);
 }
 
+/**
+ * mrp_calendar_get_name:
+ * @calendar: an #MrpCalendar
+ * 
+ * Retrieves the name of the calendar.
+ * 
+ * Return value: the calendar name.
+ **/
 const gchar *
 mrp_calendar_get_name (MrpCalendar *calendar)
 {
@@ -579,6 +610,14 @@ mrp_calendar_get_name (MrpCalendar *calendar)
 	return calendar->priv->name;
 }
 
+/**
+ * mrp_calendar_set_name:
+ * @calendar: an #MrpCalendar
+ * @name: the new name
+ *
+ * Sets the name of the calendar.
+ * 
+ **/
 void
 mrp_calendar_set_name (MrpCalendar *calendar, const gchar *name)
 {
@@ -593,13 +632,22 @@ mrp_calendar_set_name (MrpCalendar *calendar, const gchar *name)
 	priv->name = g_strdup (name);
 }
 
+/**
+ * mrp_calendar_day_set_intervals:
+ * @calendar: an #MrpCalendar
+ * @day: an #MrpDay
+ * @intervals: list of #MrpInterval to set for the specified day
+ *
+ * Overrides the working time for the day type @day when used in @calendar.
+ * 
+ **/
 void
 mrp_calendar_day_set_intervals (MrpCalendar *calendar,
 				MrpDay      *day,
-				GSList      *intervals)
+				GList      *intervals)
 {
 	MrpCalendarPriv *priv;
-	GSList          *list;
+	GList          *list;
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 
@@ -607,8 +655,8 @@ mrp_calendar_day_set_intervals (MrpCalendar *calendar,
 
 	list = g_hash_table_lookup (priv->day_intervals, day);
 	if (list) {
-		g_slist_foreach (list, (GFunc) mrp_interval_unref, NULL);
-		g_slist_free (list);
+		g_list_foreach (list, (GFunc) mrp_interval_unref, NULL);
+		g_list_free (list);
 
 		g_hash_table_remove (priv->day_intervals, day);
 	}
@@ -621,13 +669,27 @@ mrp_calendar_day_set_intervals (MrpCalendar *calendar,
 	imrp_project_set_needs_saving (priv->project, TRUE);
 }
 
-GSList *
+/**
+ * mrp_calendar_day_get_intervals:
+ * @calendar: an #MrpCalendar
+ * @day: an #MrpDay
+ * @check_ancestors: specifies if the whole calendar hierarchy should be checked
+ * 
+ * Retrieves the working time for the given day/calendar combination. If
+ * @check_ancestors is %TRUE, the calendar hierarchy is searched until a
+ * calendar that has set the working time for this day type is found. If %FALSE,
+ * the returned list will be empty if there is no explicit working time set for
+ * @calendar.
+ * 
+ * Return value: List of #MrpInterval, specifying the working time for @day.
+ **/
+GList *
 mrp_calendar_day_get_intervals (MrpCalendar *calendar,
 				MrpDay      *day,
 				gboolean     check_ancestors)
 {
 	MrpCalendarPriv *priv;
-	GSList          *list = NULL;
+	GList          *list = NULL;
 	
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
@@ -645,12 +707,21 @@ mrp_calendar_day_get_intervals (MrpCalendar *calendar,
 	return list;
 }
 
+/**
+ * mrp_calendar_day_get_total_work:
+ * @calendar: an #MrpCalendar
+ * @day: an #MrpDay
+ * 
+ * Calculates the total amount of work for @day in @calendar.
+ * 
+ * Return value: the amount of work in seconds.
+ **/
 gint
 mrp_calendar_day_get_total_work (MrpCalendar *calendar,
 				 MrpDay      *day)
 {
 	MrpCalendarPriv *priv;
-	GSList          *list, *l;
+	GList          *list, *l;
 	MrpInterval     *ival;
 	gint             total = 0;
 	mrptime          start, end;
@@ -672,6 +743,15 @@ mrp_calendar_day_get_total_work (MrpCalendar *calendar,
 	return total;
 }
 
+/**
+ * mrp_calendar_get_default_day:
+ * @calendar: an #MrpCalendar
+ * @week_day: integer in the range 0 - 6, where 0 is Sunday
+ * 
+ * Retrieves the default day for @calendar.
+ * 
+ * Return value: default #MrpDay.
+ **/
 MrpDay *
 mrp_calendar_get_default_day (MrpCalendar *calendar,
 			      gint         week_day)
@@ -685,6 +765,16 @@ mrp_calendar_get_default_day (MrpCalendar *calendar,
 	return priv->default_days[week_day];
 }
 
+/**
+ * mrp_calendar_set_default_days:
+ * @calendar: an #MrpCalendar
+ * @week_day: integer in the range 0 - 6, where 0 is Sunday
+ * @...: #MrpDay followed by more week day/#MrpDay pairs, terminated by -1
+ * 
+ * Sets days in the default week for @calendar. Those are the days that are used
+ * as fallback is a date is not overridden.
+ *
+ **/
 void
 mrp_calendar_set_default_days (MrpCalendar *calendar,
 			       gint         week_day,
@@ -717,6 +807,16 @@ mrp_calendar_set_default_days (MrpCalendar *calendar,
 	imrp_project_set_needs_saving (priv->project, TRUE);
 }
 
+/**
+ * mrp_calendar_set_days:
+ * @calendar: an #MrpCalendar
+ * @date: an #mrptime
+ * @...: #MrpDay followed by more #mrptime/#MrpDay pairs, terminated by -1
+ *
+ * Overrides specific dates in @calendar, setting the type of day to use for
+ * those dates.
+ * 
+ **/
 void
 mrp_calendar_set_days (MrpCalendar *calendar,
 		       mrptime      date,
@@ -756,6 +856,15 @@ mrp_calendar_set_days (MrpCalendar *calendar,
 	imrp_project_set_needs_saving (priv->project, TRUE);
 }
 
+/**
+ * mrp_calendar_get_parent:
+ * @calendar: an #MrpCalendar
+ * 
+ * Retrieves the parent calendar of @calendar. The parent is the calendar that a
+ * calendar falls back to if a date or day type is not overridden.
+ * 
+ * Return value: The parent calendar.
+ **/
 MrpCalendar *
 mrp_calendar_get_parent (MrpCalendar *calendar)
 {
@@ -764,7 +873,16 @@ mrp_calendar_get_parent (MrpCalendar *calendar)
 	return calendar->priv->parent;
 }
 
-GSList *
+/**
+ * mrp_calendar_get_children:
+ * @calendar: an #MrpCalendar
+ * 
+ * Retreives a list of the children, i.e. the calenderas that are immediately
+ * derived from @calendar.
+ * 
+ * Return value: List of @calendar's children.
+ **/
+GList *
 mrp_calendar_get_children (MrpCalendar *calendar)
 {
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
@@ -772,6 +890,18 @@ mrp_calendar_get_children (MrpCalendar *calendar)
 	return calendar->priv->children;
 }
 
+/**
+ * mrp_calendar_get_day:
+ * @calendar: an #MrpCalendar
+ * @date: an #mrptime
+ * @check_ancestors: specifies if the whole calendar hierarchy should be checked
+ * 
+ * Retrieves the day type for the given date and calender. If @check_ancestors
+ * is %TRUE, the parent and grandparent, and so on, is searched if @calendar
+ * does not have an overridden day type for the specified date.
+ * 
+ * Return value: An #MrpDay.
+ **/
 MrpDay *
 mrp_calendar_get_day (MrpCalendar *calendar, 
 		      mrptime      date, 
@@ -807,6 +937,15 @@ interval_free (MrpInterval *interval)
         g_free (interval);
 }
 
+/**
+ * mrp_interval_new:
+ * @start: an #mrptime specifying the start of the interval
+ * @end: an #mrptime specifying the end of the interval
+ * 
+ * Creates a new #MrpInterval ranging from @start to @end. 
+ * 
+ * Return value: The newly created interval.
+ **/
 MrpInterval *
 mrp_interval_new (mrptime         start,
                   mrptime         end)
@@ -822,6 +961,14 @@ mrp_interval_new (mrptime         start,
         return ret_val;
 }
 
+/**
+ * mrp_interval_copy:
+ * @interval: an #MrpInterval
+ * 
+ * Copies @interval.
+ * 
+ * Return value: The copied interval.
+ **/
 MrpInterval *
 mrp_interval_copy (MrpInterval *interval)
 {
@@ -832,10 +979,20 @@ mrp_interval_copy (MrpInterval *interval)
         ret_val = g_new0 (MrpInterval, 1);
         
         memcpy (ret_val, interval, sizeof (MrpInterval));
-        
+
+	ret_val->ref_count = 1;
+	
         return ret_val;
 }
 
+/**
+ * mrp_interval_ref:
+ * @interval: an #MrpInterval
+ * 
+ * Increases the reference count on @interval.
+ * 
+ * Return value: The interval.
+ **/
 MrpInterval *
 mrp_interval_ref (MrpInterval *interval)
 {
@@ -846,6 +1003,14 @@ mrp_interval_ref (MrpInterval *interval)
         return interval;
 }
 
+/**
+ * mrp_interval_unref:
+ * @interval: an #MrpInterval
+ *
+ * Decreases the reference count on @interval. When the count goes to 0, the
+ * interval is freed.
+ * 
+ **/
 void
 mrp_interval_unref (MrpInterval *interval)
 {
@@ -858,6 +1023,16 @@ mrp_interval_unref (MrpInterval *interval)
         }
 }
 
+/**
+ * mrp_interval_get_absolute:
+ * @interval: an #MrpInterval
+ * @offset: the offset to add to start and end
+ * @start: location to store start time, or %NULL
+ * @end: location to store end time, or %NULL
+ *
+ * Retrieves the start and end time of #interval, with an optional @offset.
+ * 
+ **/
 void
 mrp_interval_get_absolute (MrpInterval *interval,
 			   mrptime      offset,
@@ -876,21 +1051,31 @@ mrp_interval_get_absolute (MrpInterval *interval,
 
 static void
 foreach_day_interval_add_to_list (MrpDay  *day,
-				  GSList  *intervals, 
-				  GSList **list)
+				  GList  *intervals, 
+				  GList **list)
 {
-	DayInterval *di = g_new0 (DayInterval, 1);
+	MrpDayWithIntervals *di = g_new0 (MrpDayWithIntervals, 1);
 	di->day = day;
 	di->intervals = intervals;
 	
-	*list = g_slist_prepend (*list, di);
+	*list = g_list_prepend (*list, di);
 }
 
-GSList *
+/**
+ * mrp_calendar_get_overridden_days:
+ * @calendar: an #MrpCalendar
+ * 
+ * Retrieves the days that are overridden in this calendar, and the intervals
+ * that they are overriden with. This is mainly used when saving calendar data.
+ * 
+ * Return value: A list of #MrpDayWithIntervals structs, that must be freed
+ * (both the list and the data).
+ **/
+GList *
 mrp_calendar_get_overridden_days (MrpCalendar *calendar)
 {
 	MrpCalendarPriv *priv;
-	GSList          *ret_val = NULL;
+	GList           *ret_val = NULL;
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 	
@@ -904,20 +1089,30 @@ mrp_calendar_get_overridden_days (MrpCalendar *calendar)
 }
 
 static void
-foreach_day_add_to_list (gpointer key, MrpDay *day, GSList **list)
+foreach_day_add_to_list (gpointer key, MrpDay *day, GList **list)
 {
-	DateDay *dd = g_new0 (DateDay, 1);
+	MrpDateWithDay *dd = g_new0 (MrpDateWithDay, 1);
 	dd->date = GPOINTER_TO_INT (key);
 	dd->day  = day;
 	
-	*list = g_slist_prepend (*list, dd);
+	*list = g_list_prepend (*list, dd);
 }
 
-GSList *
+/**
+ * mrp_calendar_get_all_overridden_dates:
+ * @calendar: an #MrpCalendar
+ * 
+ * Retrieves the overridden dates of @calendar, i.e. the specific dates that
+ * differ from the parent calendar.
+ *
+ * Return value: A list of #MrpDateWithDay structs, that must be freed (both the
+ * list and the data).
+ **/
+GList *
 mrp_calendar_get_all_overridden_dates (MrpCalendar *calendar)
 {
 	MrpCalendarPriv *priv;
-	GSList          *ret_val = NULL;
+	GList           *ret_val = NULL;
 	
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 	
@@ -932,7 +1127,7 @@ mrp_calendar_get_all_overridden_dates (MrpCalendar *calendar)
 
 typedef struct {
 	MrpDay *day;
-	GSList *list;
+	GList *list;
 } MatchingDayData;
 
 static void
@@ -941,7 +1136,7 @@ foreach_matching_day_add_to_list (gpointer         key,
 				  MatchingDayData *data)
 {
 	if (day == data->day) {
-		data->list = g_slist_prepend (data->list, key);
+		data->list = g_list_prepend (data->list, key);
 	}
 }
 
@@ -952,7 +1147,7 @@ imrp_calendar_replace_day (MrpCalendar *calendar,
 {
 	MrpCalendarPriv *priv;
 	MatchingDayData  data;
-	GSList          *l;
+	GList          *l;
 	gint             i;
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
@@ -985,14 +1180,14 @@ imrp_calendar_replace_day (MrpCalendar *calendar,
 		mrp_calendar_set_days (calendar, date, new_day, -1);
 	}		
 
-	g_slist_free (data.list);
+	g_list_free (data.list);
 }
 
 static void
 calendar_emit_changed (MrpCalendar *calendar)
 {
 	MrpCalendarPriv *priv;
-	GSList          *l;
+	GList          *l;
 
 	priv = calendar->priv;
 
@@ -1021,10 +1216,10 @@ compare_intervals_func (MrpInterval *a, MrpInterval *b)
 	}
 }
 
-static GSList *
-calendar_clean_intervals (GSList *list)
+static GList *
+calendar_clean_intervals (GList *list)
 {
-	GSList *l, *sorted = NULL, *merged = NULL;
+	GList *l, *sorted = NULL, *merged = NULL;
 	MrpInterval *ival;
 	mrptime t1, t2;
 	mrptime start, end;
@@ -1039,10 +1234,10 @@ calendar_clean_intervals (GSList *list)
 			continue;
 		}
 		
-		sorted = g_slist_prepend (sorted, ival);
+		sorted = g_list_prepend (sorted, ival);
 	}
 	
-	sorted = g_slist_sort (sorted, (GCompareFunc) compare_intervals_func);
+	sorted = g_list_sort (sorted, (GCompareFunc) compare_intervals_func);
 
 	start = -1;
 	end = -1;
@@ -1061,7 +1256,7 @@ calendar_clean_intervals (GSList *list)
 			/* Store the current interval and start a new one. */
 			ival = mrp_interval_new (start, end);
 			
-			merged = g_slist_prepend (merged, ival);
+			merged = g_list_prepend (merged, ival);
 
 			start = t1;
 			end = t2;
@@ -1070,12 +1265,30 @@ calendar_clean_intervals (GSList *list)
 		/* Add the last interval if needed. */ 
 		if (!l->next && start != -1 && end != -1) {
 			ival = mrp_interval_new (start, end);
-			merged = g_slist_prepend (merged, ival);
+			merged = g_list_prepend (merged, ival);
 		}
 	}
 
-	g_slist_free (sorted);
-	merged = g_slist_reverse (merged);
+	g_list_free (sorted);
+	merged = g_list_reverse (merged);
 
 	return merged;
 }
+
+/* Boxed types. */
+
+GType
+mrp_interval_get_type (void)
+{
+	static GType our_type = 0;
+  
+	if (our_type == 0) {
+		our_type = g_boxed_type_register_static ("MrpInterval",
+							 (GBoxedCopyFunc) mrp_interval_ref,
+							 (GBoxedFreeFunc) mrp_interval_unref);
+	}
+	
+	return our_type;
+}
+
+
