@@ -206,7 +206,7 @@ task_manager_set_property (GObject      *object,
 	case PROP_PROJECT:
 		priv->project = g_value_get_object (value);
 		g_signal_connect (priv->project,
-				  "notify::project_start",
+				  "notify::project-start",
 				  G_CALLBACK (task_manager_project_start_notify_cb),
 				  manager);
 		
@@ -409,7 +409,7 @@ task_manager_traverse_cb (GNode *node, MrpTaskTraverseData *data)
  * @func: A function to call for each traversed task
  * @user_data: Argument to pass to the callback
  * 
- * Calls %func for the subtree starting at %root
+ * Calls %func for the subtree starting at %root, until @func returns %TRUE.
  * 
  **/
 void
@@ -476,43 +476,6 @@ mrp_task_manager_get_root (MrpTaskManager *manager)
 	return manager->priv->root;
 }
 
-static void
-task_manager_build_tree_copy (GNode *parent_src,
-			      GNode *parent_dst,
-			      gpointer data)
-{
-	GNode *child_src;
-	GNode *child_dst;
-
-	child_src = g_node_first_child (parent_src);
-	while (child_src) {
-		child_dst = g_node_new (child_src->data);
-		g_node_append (parent_dst, child_dst);
-
-		task_manager_build_tree_copy (child_src, child_dst, NULL);
-		
-		child_src = g_node_next_sibling (child_src);
-	}
-}
-
-/* Conveniece function for clients that want their own GNode tree. */
-GNode *
-mrp_task_manager_get_task_tree (MrpTaskManager *manager)
-{
-	GNode *root_src, *root_dst;
-	
-	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), NULL);
-
-	root_src = imrp_task_get_node (manager->priv->root);
-	root_dst = g_node_new (manager->priv->root);
-
-	task_manager_build_tree_copy (root_src, root_dst, NULL);
-
-	/*task_manager_dump_task_tree (root_dst);*/
-	
-	return root_dst;
-}
-
 gboolean
 mrp_task_manager_move_task (MrpTaskManager  *manager,
 			    MrpTask         *task,
@@ -1015,18 +978,18 @@ units_interval_new (MrpInterval *ival, gint units, gboolean is_start)
  * total units at that point, the resulting list is the return value from this
  * function.
  */
-static GSList *
+static GList *
 task_manager_get_task_units_intervals (MrpTaskManager *manager,
-				      MrpTask        *task,
-				      mrptime         date)
+				       MrpTask        *task,
+				       mrptime         date)
 {
 	MrpTaskManagerPriv *priv;
 	MrpCalendar        *calendar;
 	MrpDay             *day;
-	GSList             *ivals, *l;
+	GList              *ivals, *l;
 	MrpInterval        *ival;
-	UnitsInterval       *unit_ival, *new_unit_ival;
-	GSList             *unit_ivals = NULL;
+	UnitsInterval      *unit_ival, *new_unit_ival;
+	GList              *unit_ivals = NULL;
 	MrpAssignment      *assignment;
 	MrpResource        *resource;
 	GList              *assignments, *a;
@@ -1036,6 +999,10 @@ task_manager_get_task_units_intervals (MrpTaskManager *manager,
 	GPtrArray          *array;
 	guint               len;
 	gint                i;
+
+	if (imrp_task_get_type (task) == MRP_TASK_TYPE_MILESTONE) {
+		return NULL;
+	}
 	
 	priv = manager->priv;
 
@@ -1092,8 +1059,6 @@ task_manager_get_task_units_intervals (MrpTaskManager *manager,
 		}
 	}
 	
-	g_list_free (assignments);
-	
 	g_ptr_array_sort (array, units_interval_sort_func);
 
 	len = array->len;
@@ -1117,7 +1082,7 @@ task_manager_get_task_units_intervals (MrpTaskManager *manager,
 					new_unit_ival->start = poc;
 					new_unit_ival->end = t;
 					
-					unit_ivals = g_slist_prepend (unit_ivals, new_unit_ival);
+					unit_ivals = g_list_prepend (unit_ivals, new_unit_ival);
 				}
 			}
 				
@@ -1137,7 +1102,7 @@ task_manager_get_task_units_intervals (MrpTaskManager *manager,
 	
 	g_ptr_array_free (array, TRUE);
 
-	return g_slist_reverse (unit_ivals);
+	return g_list_reverse (unit_ivals);
 }
 
 /* Calculate the finish time from the work needed for the task, and the effort
@@ -1158,8 +1123,8 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 	gint                work;
 	gint                effort;
 	gint                delta;
-	GSList             *unit_ivals, *l;
-	UnitsInterval       *unit_ival;
+	GList              *unit_ivals, *l;
+	UnitsInterval      *unit_ival;
 	MrpTaskType         type;
 	MrpTaskSched        sched;
 	
@@ -1170,10 +1135,19 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 		return 0;
 	}
 
+	type = imrp_task_get_type (task);
+
+	if (0 && type == MRP_TASK_TYPE_MILESTONE) {
+		if (duration) {
+			*duration = 0;
+		}
+		return start;
+	}
+	
 	work = mrp_task_get_work (task);
 
 	sched = imrp_task_get_sched (task);
-	if (sched == MRP_TASK_SCHED_NORMAL) {
+	if (sched == MRP_TASK_SCHED_FIXED_WORK) {
 		*duration = 0;
 	} else {
 		*duration = mrp_task_get_duration (task);
@@ -1225,7 +1199,7 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 			}
 
 			/* Effort added by this interval. */
-			if (sched == MRP_TASK_SCHED_NORMAL) {
+			if (sched == MRP_TASK_SCHED_FIXED_WORK) {
 				delta = floor (0.5 + (double) unit_ival->units * (t2 - t1) / 100.0);
 
 				*duration += (t2 - t1);
@@ -1239,7 +1213,7 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 					goto done;
 				}
 			}
-			else if (sched == MRP_TASK_SCHED_VAR_EFFORT) {
+			else if (sched == MRP_TASK_SCHED_FIXED_DURATION) {
 				delta = t2 - t1;
 				
 				if (effort + delta >= *duration) {
@@ -1264,15 +1238,14 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 		work_start = start;
 	}
 
-	type = imrp_task_get_type (task);
 	if (type == MRP_TASK_TYPE_MILESTONE) {
 		imrp_task_set_work_start (task, start);
 	} else { 
 		imrp_task_set_work_start (task, work_start);
 	}
 	
-	g_slist_foreach (unit_ivals, (GFunc) g_free, NULL);
-	g_slist_free (unit_ivals);
+	g_list_foreach (unit_ivals, (GFunc) g_free, NULL);
+	g_list_free (unit_ivals);
 
 	return finish;
 }
@@ -1299,6 +1272,10 @@ task_manager_do_forward_pass (MrpTaskManager *manager,
 	old_start = mrp_task_get_start (task);
 	old_finish = mrp_task_get_finish (task);
 
+	/*{ gchar *name; g_object_get (task, "name", &name, NULL);
+	g_print ("task %s\n", name);
+	}*/
+	
 	if (g_node_n_children (imrp_task_get_sorted_node (task)) > 0) {
 		/* Summary task. */
 		sub_start = -1;
@@ -1321,31 +1298,31 @@ task_manager_do_forward_pass (MrpTaskManager *manager,
 		imrp_task_set_work_start (task, sub_work_start);
 		imrp_task_set_finish (task, sub_finish);
 
-		duration = sub_finish - sub_start;
-
 		/* FIXME: should work be the sum of the work of the children
 		 * here? The problem is that summary tasks really display
 		 * duration in the work field. That's why we set duration to the
 		 * same value as work below.
 		 */
 		
-		work = mrp_task_manager_calculate_task_work (manager, task, duration);
+		work = mrp_task_manager_calculate_task_work (manager,
+							     task,
+							     sub_start,
+							     sub_finish);
 		imrp_task_set_work (task, work);
 		imrp_task_set_duration (task, work);
 	} else {
 		/* Non-summary task. */
+		
 		t1 = task_manager_calculate_task_start (manager, task);
 		t2 = task_manager_calculate_task_finish (manager, task, t1, &duration);
+		
+		imrp_task_set_start (task, t1);
+		imrp_task_set_finish (task, t2);
 
 		sched = imrp_task_get_sched (task);
-		if (sched == MRP_TASK_SCHED_NORMAL) {
-			imrp_task_set_start (task, t1);
-			imrp_task_set_finish (task, t2);
+		if (sched == MRP_TASK_SCHED_FIXED_WORK) {
 			imrp_task_set_duration (task, duration);
 		} else {
-			imrp_task_set_start (task, t1);
-			imrp_task_set_finish (task, t2);
-
 			duration = mrp_task_get_duration (task);
 			work = mrp_task_get_work (task);
 			
@@ -1354,28 +1331,27 @@ task_manager_do_forward_pass (MrpTaskManager *manager,
 				GList         *assignments, *a;
 				MrpAssignment *assignment;
 				gint           n, units;
-
+				
 				assignments = mrp_task_get_assignments (task);
-
+				
 				n = g_list_length (assignments);
 				units = floor (0.5 + 100.0 * (gdouble) work / duration / n);
 				
 				for (a = assignments; a; a = a->next) {
 					assignment = a->data;
-
+					
 					g_signal_handlers_block_by_func (assignment,
 									 task_manager_assignment_units_notify_cb,
 									 manager);
-
+					
 					g_object_set (assignment, "units", units, NULL);
-
+					
 					g_signal_handlers_unblock_by_func (assignment,
 									   task_manager_assignment_units_notify_cb,
 									   manager);
-
-
+					
+					
 				}
-				g_list_free (assignments);
 			}
 		}		
 	}
@@ -1853,14 +1829,14 @@ static gint
 task_manager_get_work_for_calendar (MrpTaskManager *manager,
 				    MrpCalendar    *calendar,
 				    mrptime         start,
-				    mrptime         end)
+				    mrptime         finish)
 {
 	MrpTaskManagerPriv *priv;
 	mrptime             t;
 	mrptime             t1, t2;
 	gint                work;
 	MrpDay             *day;
-	GSList             *ivals, *l;
+	GList              *ivals, *l;
 	MrpInterval        *ival;
 
 	priv = manager->priv;
@@ -1868,11 +1844,11 @@ task_manager_get_work_for_calendar (MrpTaskManager *manager,
 	work = 0;
 
 	/* Loop through the intervals of the calendar and add up the work, until
-	 * the end time is hit.
+	 * the finish time is hit.
 	 */
 	t = mrp_time_align_day (start);
 
-	while (t < end) {
+	while (t < finish) {
 		day = mrp_calendar_get_day (calendar, t, TRUE);
 		ivals = mrp_calendar_day_get_intervals (calendar, day, TRUE);
 
@@ -1887,13 +1863,13 @@ task_manager_get_work_for_calendar (MrpTaskManager *manager,
 			}
 			
 			/* Stop if the interval starts after the task. */
-			if (t1 >= end) {
+			if (t1 >= finish) {
 				break;
 			}
 			
 			/* Don't add time outside the task. */
 			t1 = MAX (t1, start);
-			t2 = MIN (t2, end);
+			t2 = MIN (t2, finish);
 			
 			work += t2 - t1;
 		}
@@ -1904,41 +1880,42 @@ task_manager_get_work_for_calendar (MrpTaskManager *manager,
 	return work;
 }
 
-/* Calculate the work needed to achieve the specified duration, with the
+/* Calculate the work needed to achieve the specified start and finish, with the
  * allocated resources' calendars in consideration.
  */
 gint
 mrp_task_manager_calculate_task_work (MrpTaskManager *manager,
 				      MrpTask        *task,
-				      gint            duration)
+				      mrptime         start,
+				      mrptime         finish)
 {
 	MrpTaskManagerPriv *priv;
-	mrptime             start;
-	mrptime             end;
-	gint                work;
+	gint                work = 0;
 	MrpAssignment      *assignment;
 	MrpResource        *resource;
 	GList              *assignments, *a;
 	MrpCalendar        *calendar;
 
-	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), 0);
-	g_return_val_if_fail (MRP_IS_TASK (task), 0);
-	g_return_val_if_fail (duration >= 0, 0);
-
 	priv = manager->priv;
 
 	if (task == priv->root) {
 		return 0;
 	}
+
+	if (start == -1) {
+		/* FIXME: why did we use task_manager_calculate_task_start
+		 * (manager, task) here?? Shouldn't be needed...
+		 */
+		start = mrp_task_get_start (task);
+	}
+
+	if (finish <= start) {
+		return 0;
+	}
 	
-	work = 0;
-
-	start = task_manager_calculate_task_start (manager, task);
-	end = start + duration;
-
 	/* Loop through the intervals of the assigned resources' calendars (or
 	 * the project calendar if no resources are assigned), and add up the
-	 * work, until duration is hit.
+	 * work.
 	 */
 
 	assignments = mrp_task_get_assignments (task);
@@ -1955,7 +1932,7 @@ mrp_task_manager_calculate_task_work (MrpTaskManager *manager,
 		work += task_manager_get_work_for_calendar (manager,
 							    calendar,
 							    start,
-							    end);
+							    finish);
 	}
 	
 	if (!assignments) {
@@ -1964,7 +1941,7 @@ mrp_task_manager_calculate_task_work (MrpTaskManager *manager,
 		work = task_manager_get_work_for_calendar (manager,
 							   calendar,
 							   start,
-							   end);
+							   finish);
 	}
 
 	return work;
