@@ -117,7 +117,7 @@ struct _MrpTaskPriv {
 	MrpConstraint     constraint;
 
 	/* List of assignments. */
-	GHashTable       *assignments;
+	GList            *assignments;
 };
 
 
@@ -181,7 +181,7 @@ task_init (MrpTask *task)
 	priv->name = g_strdup ("");
 	priv->node = g_node_new (task);
 	priv->sorted_node = g_node_new (task);
-	priv->assignments = g_hash_table_new (NULL, NULL);
+	priv->assignments = NULL;
 	priv->constraint.type = MRP_CONSTRAINT_ASAP;
 }
 
@@ -268,8 +268,8 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_NAME,
 		g_param_spec_string ("name",
-				     "Task name",
-				     NULL,
+				     "Name",
+				     "Name of the task",
 				     "",
 				     G_PARAM_READWRITE));
 	
@@ -277,8 +277,8 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_NOTE,
 		g_param_spec_string ("note",
-				     "Task note",
-				     NULL,
+				     "Note",
+				     "Note attached to the task",
 				     "",
 				     G_PARAM_READWRITE));
 
@@ -286,40 +286,40 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_START,
 		mrp_param_spec_time ("start",
-				     "Task start time",
-				     NULL,
+				     "Start time",
+				     "Task Start time",
 				     G_PARAM_READABLE));
 	
 	g_object_class_install_property (
 		object_class,
 		PROP_FINISH,
 		mrp_param_spec_time ("finish",
+				     "Finish time",
 				     "Task finish time",
-				     NULL,
 				     G_PARAM_READABLE));
 	
 	g_object_class_install_property (
 		object_class,
 		PROP_LATEST_START,
 		mrp_param_spec_time ("latest_start",
+				     "Latest start",
 				     "Latest task start time",
-				     NULL,
 				     G_PARAM_READABLE));
 	
 	g_object_class_install_property (
 		object_class,
 		PROP_LATEST_FINISH,
 		mrp_param_spec_time ("latest_finish",
+				     "Latest finish",
 				     "Latest task finish time",
-				     NULL,
 				     G_PARAM_READABLE));
 	
 	g_object_class_install_property (
 		object_class,
 		PROP_DURATION,
 		g_param_spec_int ("duration",
-				  "Task duration",
-				  NULL,
+				  "Duration",
+				  "Duration of the task",
 				  -1, G_MAXINT, 0,
 				  G_PARAM_READWRITE));
 
@@ -327,8 +327,8 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_WORK,
 		g_param_spec_int ("work",
+				  "Work",
 				  "Task work",
-				  NULL,
 				  -1, G_MAXINT, 0,
 				  G_PARAM_READWRITE));
 
@@ -336,8 +336,8 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_CRITICAL,
 		g_param_spec_boolean ("critical",
+				      "Critical",
 				      "In critical path",
-				      NULL,
 				      FALSE,
 				      G_PARAM_READWRITE));
 
@@ -345,8 +345,8 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_TYPE,
 		g_param_spec_enum ("type",
+				   "Type",
 				   "Task type",
-				   NULL,
 				   MRP_TYPE_TASK_TYPE,
 				   MRP_TASK_TYPE_NORMAL,
 				   G_PARAM_READWRITE));
@@ -355,18 +355,18 @@ task_class_init (MrpTaskClass *klass)
 		object_class,
 		PROP_SCHED,
 		g_param_spec_enum ("sched",
+				   "Sceduling type",
 				   "Task scheduling type",
-				   NULL,
 				   MRP_TYPE_TASK_SCHED,
-				   MRP_TASK_SCHED_NORMAL,
+				   MRP_TASK_SCHED_FIXED_WORK,
 				   G_PARAM_READWRITE));
 
 	g_object_class_install_property (
 		object_class,
 		PROP_CONSTRAINT,
 		g_param_spec_boxed ("constraint",
-				    "Time constraint",
-				    NULL,
+				    "Constraint",
+				    "Task scheduling constraint",
 				    MRP_TYPE_CONSTRAINT,
 				    G_PARAM_READWRITE));
 	
@@ -375,7 +375,7 @@ task_class_init (MrpTaskClass *klass)
 		PROP_PERCENT_COMPLETE,
 		g_param_spec_int ("percent_complete",
 				  "Percent complete",
-				  NULL,
+				  "Percent completed of task",
 				  0, 100, 0,
 				  G_PARAM_READWRITE));
 }
@@ -463,7 +463,7 @@ task_set_property (GObject      *object,
 			return;
 		}
 
-		if (priv->sched == MRP_TASK_SCHED_NORMAL) {
+		if (priv->sched == MRP_TASK_SCHED_FIXED_WORK) {
 			return;
 		}
 		
@@ -546,7 +546,7 @@ task_set_property (GObject      *object,
 	}
 
 	if (changed) {
-		mrp_object_set_needs_saving (MRP_OBJECT (object), TRUE);
+		mrp_object_changed (MRP_OBJECT (object));
 	}
 }
 
@@ -631,25 +631,18 @@ static void
 task_assignment_removed_cb (MrpAssignment *assignment, MrpTask *task)
 {
 	MrpTaskPriv *priv;
-	MrpResource *resource;
 	
 	g_return_if_fail (MRP_IS_TASK (task));
 	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
 	
 	priv = task->priv;
 
-	resource = mrp_assignment_get_resource (assignment);
-	
-	if (!resource) {
-		g_warning ("Resource not found in tasks assignments list");
-		return;
-	}
-	
-	g_hash_table_remove (priv->assignments, resource);
+	priv->assignments = g_list_remove (priv->assignments, assignment);
+
 	g_signal_emit (task, signals[ASSIGNMENT_REMOVED], 0, assignment);
 	g_object_unref (assignment);
 
-	mrp_object_set_needs_saving (MRP_OBJECT (task), TRUE);
+	mrp_object_changed (MRP_OBJECT (task));
 }
 
 static void
@@ -690,41 +683,28 @@ task_remove_relations (MrpTask *task)
 	}
 }
 
-static gboolean
-foreach_remove_assignment (gpointer key, gpointer value, gpointer data)
-{
-	return TRUE;
-}
-
 static void
 task_remove_assignments (MrpTask *task)
 {
 	MrpTaskPriv   *priv;
-	GList         *list, *l;
+	GList         *l;
 	MrpAssignment *assignment;
 
 	g_return_if_fail (MRP_IS_TASK (task));
 
 	priv = task->priv;
 
-	/* Remove all assignments, without corrupting the hashtable on the fly.
-	 */
-	list = mrp_task_get_assignments (task);
-
-	g_hash_table_foreach_remove (priv->assignments, 
-				     (GHRFunc) foreach_remove_assignment,
-				     task);
-	
-	for (l = list; l; l = l->next) {
+	for (l = priv->assignments; l; l = l->next) {
 		assignment = l->data;
 		
 		g_signal_handlers_disconnect_by_func (assignment,
 						      task_assignment_removed_cb,
 						      task);
+		g_object_unref (assignment);
 		mrp_object_removed (MRP_OBJECT (assignment));
 	}
 	
-	g_list_free (list);
+	g_list_free (priv->assignments);
 }
 
 static gboolean
@@ -746,7 +726,7 @@ task_remove_subtree_cb (GNode *node, gpointer data)
 	
 	return FALSE;
 }
-				 
+
 void
 imrp_task_remove_subtree (MrpTask *task)
 {
@@ -857,6 +837,13 @@ imrp_task_reattach_pos (MrpTask  *task,
 		       task->priv->node);
 }
 
+/**
+ * mrp_task_new:
+ * 
+ * Create a new task.
+ * 
+ * Return value: the newly created #MrpTask.
+ **/
 MrpTask *
 mrp_task_new (void)
 {
@@ -867,6 +854,37 @@ mrp_task_new (void)
 	return task;
 }
 
+/**
+ * mrp_task_get_name:
+ * @task: an #MrpTask
+ * 
+ * Retrives the name of @task.
+ * 
+ * Return value: the name
+ **/
+const gchar *
+mrp_task_get_name (MrpTask *task)
+{
+	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
+
+	return task->priv->name;
+}
+
+/**
+ * mrp_task_set_name:
+ * @task: an #MrpResource
+ * @name: new name of @task
+ * 
+ * Sets the name of @task.
+ **/
+void mrp_task_set_name (MrpTask *task, const gchar *name)
+{
+	g_return_if_fail (MRP_IS_TASK (task));
+	g_return_if_fail (name != NULL);
+	
+	mrp_object_set (MRP_OBJECT (task), "name", name, NULL);
+}
+
 void
 imrp_task_insert_child (MrpTask *parent,
 			gint     position,
@@ -925,13 +943,31 @@ task_get_successor_relation (MrpTask *task,
 	return NULL;
 }
 
+/**
+ * mrp_task_has_relation_to:
+ * @task_a: an #MrpTask
+ * @task_b: an #MrpTask
+ * 
+ * Checks if @a and @b has a relation, i.e. if a is a predecessor or successor
+ * of b.
+ * 
+ * Return value: %TRUE if @a and @b has a relation
+ **/
 gboolean
-mrp_task_has_relation_to (MrpTask *a, MrpTask *b)
+mrp_task_has_relation_to (MrpTask *task_a, MrpTask *task_b)
 {
-	return (task_get_predecessor_relation (a, b) != NULL) ||
-		(task_get_predecessor_relation (b, a) != NULL);
+	return (task_get_predecessor_relation (task_a, task_b) != NULL) ||
+		(task_get_predecessor_relation (task_b, task_a) != NULL);
 }
 
+/**
+ * mrp_task_has_relation:
+ * @task: an #MrpTask
+ * 
+ * Checks if a task has any relations, i.e. predecessors or successors.
+ * 
+ * Return value: %TRUE if there are any relations.
+ **/
 gboolean
 mrp_task_has_relation (MrpTask *task)
 {
@@ -941,16 +977,17 @@ mrp_task_has_relation (MrpTask *task)
 
 /**
  * mrp_task_add_predecessor:
- * @task: The task to add predecessor to
- * @predecessor: The predecessor
- * @type: Type of relation
- * @lag: Lag time. If negative, it means lead time.
+ * @task: an #MrpTask
+ * @predecessor: the predecessor
+ * @type: type of relation
+ * @lag: lag time, if negative, it means lead time
+ * @error: location to store error, or %NULL
  * 
  * Adds a predecessor task to a task. Depending on type, the predecessor
  * must be started or finished before task can be started or finished,
- * with an optional lag/lead.
+ * with an optional lag/lead time.
  *
- * Return value: The relation that represents the predecessor/successor link.
+ * Return value: the relation that represents the predecessor/successor link.
  **/
 MrpRelation *
 mrp_task_add_predecessor (MrpTask          *task,
@@ -977,12 +1014,17 @@ mrp_task_add_predecessor (MrpTask          *task,
 	}
 
 	g_object_get (task, "project", &project, NULL);
-	manager = mrp_project_get_task_manager (project);
+	manager = imrp_project_get_task_manager (project);
 	if (!mrp_task_manager_check_predecessor (manager, task, predecessor, error)) {
 		return NULL;
 	}
 	
-	relation = mrp_relation_new (task, predecessor, type, lag);
+	relation = g_object_new (MRP_TYPE_RELATION,
+				 "successor", task,
+				 "predecessor", predecessor,
+				 "type", type,
+				 "lag", lag,
+				 NULL);
 
 	task->priv->predecessors = g_list_prepend (task->priv->predecessors, relation);
 	predecessor->priv->successors = g_list_prepend (predecessor->priv->successors, relation);
@@ -990,16 +1032,16 @@ mrp_task_add_predecessor (MrpTask          *task,
 	g_signal_emit (task, signals[RELATION_ADDED], 0, relation);
 	g_signal_emit (predecessor, signals[RELATION_ADDED], 0, relation);
 
-	mrp_object_set_needs_saving (MRP_OBJECT (task), TRUE);
-	mrp_object_set_needs_saving (MRP_OBJECT (predecessor), TRUE);
+	mrp_object_changed (MRP_OBJECT (task));
+	mrp_object_changed (MRP_OBJECT (predecessor));
 
 	return relation;
 }
 
 /**
  * mrp_task_remove_predecessor:
- * @task: The task to remove a predecessor from
- * @predecessor: The predecessor to remove
+ * @task: an #MrpTask
+ * @predecessor: the predecessor to remove
  * 
  * Removes a predecessor previously added to task.
  **/
@@ -1023,8 +1065,8 @@ mrp_task_remove_predecessor (MrpTask *task,
 	g_signal_emit (task, signals[RELATION_REMOVED], 0, relation);
 	g_signal_emit (predecessor, signals[RELATION_REMOVED], 0, relation);
 
-	mrp_object_set_needs_saving (MRP_OBJECT (task), TRUE);
-	mrp_object_set_needs_saving (MRP_OBJECT (predecessor), TRUE);
+	mrp_object_changed (MRP_OBJECT (task));
+	mrp_object_changed (MRP_OBJECT (predecessor));
 
 	/* FIXME: ? */
 	g_object_unref (relation);
@@ -1032,15 +1074,16 @@ mrp_task_remove_predecessor (MrpTask *task,
 
 /**
  * mrp_task_get_relation:
- * @task_a: A task 
- * @task_b: A task
+ * @task_a: an #MrpTask
+ * @task_b: an #MrpTask
  * 
+ * Fetches a relation between two tasks if it exists.
  * 
- * Return value: Any relation between two tasks.
+ * Return value: a #MrpRelation representing the relation between @task_a and 
+ * @task_b or %NULL if they don't have any relation.
  **/
 MrpRelation *
-mrp_task_get_relation (MrpTask *task_a,
-		       MrpTask *task_b)
+mrp_task_get_relation (MrpTask *task_a, MrpTask *task_b)
 {
 	MrpRelation *relation;
 	
@@ -1056,39 +1099,34 @@ mrp_task_get_relation (MrpTask *task_a,
 }
 
 /**
- * mrp_task_get_predecessor:
- * @task: 
- * @predecessor: 
+ * mrp_task_get_predecessor_relation:
+ * @task: an #MrpTask
+ * @predecessor: #an MrpTask
  * 
+ * Fetches a predecessor relation between task and it's predecessor.
  * 
- * 
- * Return value: 
+ * Return value: the #MrpRelation if it exists, otherwise %NULL
  **/
 MrpRelation *
-mrp_task_get_predecessor (MrpTask *task,
-			  MrpTask *predecessor)
+mrp_task_get_predecessor_relation (MrpTask *task, MrpTask *predecessor)
 {
-	MrpRelation *relation;
-	
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 	g_return_val_if_fail (MRP_IS_TASK (predecessor), NULL);
 	
-	relation = task_get_predecessor_relation (task, predecessor);
-	return relation;
+	return task_get_predecessor_relation (task, predecessor);
 }
 
 /**
- * mrp_task_get_successor:
- * @task: 
- * @successor: 
+ * mrp_task_get_successor_relation:
+ * @task: an #MrpTask
+ * @successor: an #MrpTask
  * 
+ * Fetches a successor relation between task and it's successor.
  * 
- * 
- * Return value: 
+ * Return value: the #MrpRelation if it exists, otherwise %NULL
  **/
 MrpRelation *
-mrp_task_get_successor (MrpTask *task,
-			MrpTask *successor)
+mrp_task_get_successor_relation (MrpTask *task, MrpTask *successor)
 {
 	MrpRelation *relation;
 	
@@ -1099,22 +1137,46 @@ mrp_task_get_successor (MrpTask *task,
 	return relation;
 }
 
+/**
+ * mrp_task_get_predecessor_relations:
+ * @task: an #MrpTask
+ * 
+ * Fetches a list of predecessor relations to @task. 
+ * 
+ * Return value: the list of predecessor relations to @task
+ **/
 GList *
-mrp_task_get_predecessors (MrpTask *task)
+mrp_task_get_predecessor_relations (MrpTask *task)
 {
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 
-	return g_list_copy (task->priv->predecessors);
+	return task->priv->predecessors;
 }
 
+/**
+ * mrp_task_get_successor_relations:
+ * @task: an #MrpTask
+ * 
+ * Fetches a list of successor relations to @task. 
+ * 
+ * Return value: a list of successor relations to @task
+ **/
 GList *
-mrp_task_get_successors (MrpTask *task)
+mrp_task_get_successor_relations (MrpTask *task)
 {
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 
-	return g_list_copy (task->priv->successors);
+	return task->priv->successors;
 }
 
+/**
+ * mrp_task_get_parent:
+ * @task: an #MrpTask
+ * 
+ * Fetches the parent of @task.
+ * 
+ * Return value: the parent of @task, or %NULL if there is no parent..
+ **/
 MrpTask *
 mrp_task_get_parent (MrpTask *task)
 {
@@ -1126,6 +1188,14 @@ mrp_task_get_parent (MrpTask *task)
 	return node ? node->data : NULL;
 }
 
+/**
+ * mrp_task_get_first_child:
+ * @task: an #MrpTask
+ * 
+ * Fetches the first child of @task.
+ * 
+ * Return value: the first child of @task, or %NULL if there are no children.
+ **/
 MrpTask *
 mrp_task_get_first_child (MrpTask *task)
 {
@@ -1137,6 +1207,15 @@ mrp_task_get_first_child (MrpTask *task)
 	return node ? node->data : NULL;
 }
 
+/**
+ * mrp_task_get_next_sibling:
+ * @task: an #MrpTask
+ * 
+ * Fetches the next sibling of @task.
+ * 
+ * Return value: the next sibling of @task, or %NULL if there is no next
+ * sibling.
+ **/
 MrpTask *
 mrp_task_get_next_sibling (MrpTask *task)
 {
@@ -1148,6 +1227,14 @@ mrp_task_get_next_sibling (MrpTask *task)
 	return node ? node->data : NULL;
 }
 
+/**
+ * mrp_task_get_n_children:
+ * @task: an #MrpTask
+ * 
+ * Fetches the number of children @task has.
+ * 
+ * Return value: the number of children @task has
+ **/
 guint
 mrp_task_get_n_children (MrpTask *task)
 {
@@ -1156,6 +1243,15 @@ mrp_task_get_n_children (MrpTask *task)
 	return g_node_n_children (task->priv->node);
 }
 
+/**
+ * mrp_task_get_nth_child:
+ * @task: an #MrpTask
+ * @n: the index of the child to get
+ * 
+ * Fetches the nth child of @task.
+ * 
+ * Return value: the nth child of @task, or %NULL if there is no such child.
+ **/
 MrpTask *
 mrp_task_get_nth_child (MrpTask *task, guint n)
 {
@@ -1167,6 +1263,14 @@ mrp_task_get_nth_child (MrpTask *task, guint n)
 	return node ? node->data : NULL;
 }
 
+/**
+ * mrp_task_get_position:
+ * @task: an #MrpTask
+ * 
+ * Fetches the index or position of @task among its siblings.
+ * 
+ * Return value: the position of @task among its siblings.
+ **/
 gint
 mrp_task_get_position (MrpTask *task)
 {
@@ -1180,9 +1284,15 @@ mrp_task_get_position (MrpTask *task)
 	return g_node_child_position (parent, task->priv->node);
 }
 
+/**
+ * mrp_task_add_assignment:
+ * @task: an #MrpTask
+ * @assignment: an #MrpAssignment
+ * 
+ * Adds an assignment to @task.
+ **/
 void
-mrp_task_add_assignment (MrpTask       *task,
-			 MrpAssignment *assignment)
+imrp_task_add_assignment (MrpTask *task, MrpAssignment *assignment)
 {
 	MrpTaskPriv *priv;
 	
@@ -1191,9 +1301,8 @@ mrp_task_add_assignment (MrpTask       *task,
 	
 	priv = task->priv;
 	
-	g_hash_table_insert (priv->assignments, 
-			     mrp_assignment_get_resource (assignment),
-			     g_object_ref (assignment));
+	priv->assignments = g_list_prepend (priv->assignments, 
+					    g_object_ref (assignment));
 
 	g_signal_connect (assignment,
 			  "removed",
@@ -1202,9 +1311,17 @@ mrp_task_add_assignment (MrpTask       *task,
 
 	g_signal_emit (task, signals[ASSIGNMENT_ADDED], 0, assignment);
 
-	mrp_object_set_needs_saving (MRP_OBJECT (task), TRUE);
+	mrp_object_changed (MRP_OBJECT (task));
 }
 
+/**
+ * mrp_task_get_start:
+ * @task: an #MrpTask
+ * 
+ * Fetches the start time of @task.
+ * 
+ * Return value: the start time of @task.
+ **/
 mrptime
 mrp_task_get_start (MrpTask *task)
 {
@@ -1213,6 +1330,14 @@ mrp_task_get_start (MrpTask *task)
 	return task->priv->start;
 }
 
+/**
+ * mrp_task_get_finish:
+ * @task: an #MrpTask
+ * 
+ * Fetches the finish time of @task.
+ * 
+ * Return value: the finish time of @task.
+ **/
 mrptime
 mrp_task_get_finish (MrpTask *task)
 {
@@ -1221,6 +1346,17 @@ mrp_task_get_finish (MrpTask *task)
 	return task->priv->finish;
 }
 
+/**
+ * mrp_task_get_work_start:
+ * @task: an #MrpTask
+ * 
+ * Retrieves the first time where work is performed of @task. This might be
+ * different from the start time, if the start time is during non-working
+ * time. In that case, the work start would be right after the non-working
+ * interval.
+ * 
+ * Return value: The work start time of @task.
+ **/
 mrptime
 mrp_task_get_work_start (MrpTask *task)
 {
@@ -1229,18 +1365,45 @@ mrp_task_get_work_start (MrpTask *task)
 	return task->priv->work_start;
 }
 
+/**
+ * mrp_task_get_latest_start:
+ * @task: an #MrpTask
+ * 
+ * Retrieves the latest start time of @task, i.e. the latest time the task can
+ * start without delaying the project.
+ * 
+ * Return value: The latest start time of @task.
+ **/
 mrptime
 mrp_task_get_latest_start (MrpTask *task)
 {
 	return task->priv->latest_start;
 }
 
+/**
+ * mrp_task_get_latest_finish:
+ * @task: an #MrpTask
+ * 
+ * Retrieves the latest finish time of @task, i.e. the latest time the task can
+ * finish without delaying the project.
+ * 
+ * Return value: The latest finish time of @task.
+ **/
 mrptime
 mrp_task_get_latest_finish (MrpTask *task)
 {
 	return task->priv->latest_finish;
 }
 
+/**
+ * mrp_task_get_duration:
+ * @task: an #MrpTask
+ * 
+ * Fetches the duration of @task. This differs from the calendar duration that
+ * is retrieved by (finish - start).
+ * 
+ * Return value: The duration of @task.
+ **/
 gint
 mrp_task_get_duration (MrpTask *task)
 {
@@ -1249,6 +1412,14 @@ mrp_task_get_duration (MrpTask *task)
 	return task->priv->duration;
 }
 
+/**
+ * mrp_task_get_work:
+ * @task: an #MrpTask
+ * 
+ * Retrieves the amount of work of @task.
+ * 
+ * Return value: The work of @task.
+ **/
 gint
 mrp_task_get_work (MrpTask *task)
 {
@@ -1257,75 +1428,101 @@ mrp_task_get_work (MrpTask *task)
 	return task->priv->work;
 }
 
-static void
-foreach_assignment_add_to_list (gpointer key,
-				gpointer value, 
-				gpointer user_data)
-{
-	GList **list;
-	
-	list = (GList **) user_data;
-	
-	*list = g_list_prepend (*list, value);
-}
-
+/**
+ * mrp_task_get_assignments:
+ * @task: an #MrpTask
+ * 
+ * Fetches a list of #MrpAssignment.
+ * 
+ * Return value: the list of assignments.
+ **/
 GList *
 mrp_task_get_assignments (MrpTask *task)
 {
-	GList *list = NULL;
-	
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 	
-	g_hash_table_foreach (task->priv->assignments, 
-			      foreach_assignment_add_to_list,
-			      &list);
-			      
-	return list;
+	return task->priv->assignments;
 }
 
+/**
+ * mrp_task_get_assignment:
+ * @task: an #MrpTask
+ * @resource: an #MrpResource
+ * 
+ * retrieves the #MrpAssignment associated with @task and @resource if the
+ * resource is assigned to @task, or %NULL if there is no such assignment.
+ * 
+ * Return value: The assignment if it exists, otherwise %NULL.
+ **/
 MrpAssignment *
 mrp_task_get_assignment (MrpTask *task, MrpResource *resource)
 {
+	GList *l;
+	
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
 
-	return g_hash_table_lookup (task->priv->assignments, resource);
+	for (l = task->priv->assignments; l; l = l->next) {
+		MrpAssignment *assignment = l->data;
+		
+		if (mrp_assignment_get_resource (assignment) == resource) {
+			return assignment;
+		}
+	}
+	
+	return NULL;
 }
 
+/**
+ * mrp_task_get_assigned_resources:
+ * @task: an #MrpTask
+ * 
+ * Fetches a list of resources assigned to @task. The list needs to be freed 
+ * with g_list_free() by caller.
+ * 
+ * Return value: A newly created list of #MrpResource.
+ **/
 GList *
 mrp_task_get_assigned_resources (MrpTask *task)
 {
-	GList         *list = NULL;
-	GList         *assignments;
-	GList         *node;
-	MrpAssignment *assignment;
-	MrpResource   *resource;
+	GList *list = NULL;
+	GList *l;
 	
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 
-	assignments = mrp_task_get_assignments (task);
-	
-	for (node = assignments; node; node = node->next) {
-		assignment = MRP_ASSIGNMENT (node->data);
-		resource   = MRP_RESOURCE (
-			mrp_assignment_get_resource (assignment));
-		
-		list = g_list_prepend (list, resource);
+	for (l = task->priv->assignments; l; l = l->next) {
+		MrpAssignment *assignment = l->data;
+
+		list = g_list_prepend (
+			list, mrp_assignment_get_resource (assignment));
 	}
-
+	
 	list = g_list_sort (list, mrp_resource_compare);
-
-	g_list_free (assignments);
-
+	
 	return list;
 }
 
+/**
+ * mrp_task_compare:
+ * @a: an #MrpTask
+ * @b: an #MrpTask
+ * 
+ * Compares the name of the tasks, by calling strcmp() on the names.
+ * 
+ * Return value: the return value of strcmp (a->name, b->name).
+ **/
 gint
 mrp_task_compare (gconstpointer a, gconstpointer b)
 {
 	return strcmp (MRP_TASK (a)->priv->name, MRP_TASK (b)->priv->name);
 }
 
+/**
+ * mrp_task_reset_constraint:
+ * @task: an #MrpTask
+ * 
+ * Sets the contraint type to %MRP_CONTRAINT_ASAP and notifies listeners.
+ **/
 void
 mrp_task_reset_constraint (MrpTask *task)
 {
@@ -1339,46 +1536,37 @@ mrp_task_reset_constraint (MrpTask *task)
 
 /**
  * mrp_task_get_cost:
- * @task: A task object
+ * @task: an #MrpTask
  * 
+ * Calculates the cost to complete @task.
  * 
- * 
- * Return value: the cost to complete the task
+ * Return value: The cost to complete @task.
  **/
 gfloat
 mrp_task_get_cost (MrpTask *task)
 {
 	MrpTaskPriv *priv;
-	MrpProject  *project;
-	GList       *resources, *l;
+	GList       *assignments, *l;
+	MrpResource *resource;
 	gfloat       total = 0;
 	gfloat       cost;
-	gint         work;
-	
+
 	g_return_val_if_fail (MRP_IS_TASK (task), 0);
 
+	/* FIXME: why don't we cache this in priv->cost and recalculate in
+	 * reschedule? This is called a lot from the tree view...
+	 */
+
 	priv = task->priv;
 
-	g_object_get (task, "project", &project, NULL);
-	
-	resources = mrp_task_get_assigned_resources (task);
+	assignments = mrp_task_get_assignments (task);
+	for (l = assignments; l; l = l->next) {
+		resource = mrp_assignment_get_resource (l->data);
 
-	for (l = resources; l; l = l->next) {		
-		mrp_object_get (l->data, "cost", &cost, NULL);
-
-		/* FIXME: Hm, couldn't we use the work stored in the task? would be much faster */
-		work = mrp_project_calculate_task_work (project,
-							task,
-							mrp_task_get_duration (task));
-		
-		/* Like this */
-		/*work = priv->work;*/
-		
-		total += work / 3600 * cost;
+		mrp_object_get (resource, "cost", &cost, NULL);
+		total += priv->work / 3600.0 * cost;
 	}
 
-	g_list_free (resources);
-	
 	return total;
 }
 
@@ -1550,7 +1738,7 @@ imrp_task_get_type (MrpTask *task)
 MrpTaskSched
 imrp_task_get_sched (MrpTask *task)
 {
-	g_return_val_if_fail (MRP_IS_TASK (task), MRP_TASK_SCHED_NORMAL);
+	g_return_val_if_fail (MRP_IS_TASK (task), MRP_TASK_SCHED_FIXED_WORK);
 
 	return task->priv->sched;
 }
