@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2002 CodeFactory AB
- * Copyright (C) 2002 Richard Hult <rhult@codefactory.se>
+ * Copyright (C) 2002-2003 CodeFactory AB
+ * Copyright (C) 2002-2003 Richard Hult <rhult@codefactory.se>
  * Copyright (C) 2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This library is free software; you can redistribute it and/or
@@ -25,84 +25,34 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <langinfo.h>
 #include "mrp-time.h"
 #include "mrp-types.h"
 #include "mrp-intl.h"
 #include "mrp-private.h"
 
-static const gchar *short_month_names[] = {
-/* i18n: abbreviated month names.  */
-	N_("Jan"),
-	N_("Feb"),
-	N_("Mar"),
-	N_("Apr"),
-	N_("May"),
-	N_("Jun"),
-	N_("Jul"),
-	N_("Aug"),
-	N_("Sep"),
-	N_("Oct"),
-	N_("Nov"),
-	N_("Dec")
-};
+static const gchar *short_month_names[12];
+static const gchar *month_names[12];
 
-/* i18n: full month names.  */
-static const gchar *month_names[] = {
-	N_("January"),
-	N_("February"),
-	N_("March"),
-	N_("April"),
-	N_("May"),
-	N_("June"),
-	N_("July"),
-	N_("August"),
-	N_("September"),
-	N_("October"),
-	N_("November"),
-	N_("December")
-};
-
-static const gchar *month_names_initial[] = {
-/* i18n: month name initials, only the part before the space is used, but the
- * numbers are used to differentiate the otherwise identical strings. */
-	N_("J 1"),
-	N_("F 2"),
-	N_("M 3"),
-	N_("A 4"),
-	N_("M 5"),
-	N_("J 6"),
-	N_("J 7"),
-	N_("A 8"),
-	N_("S 9"),
-	N_("O 10"),
-	N_("N 11"),
-	N_("D 12")
-};
-
-static const gchar *short_day_names[] = {
-/* i18n: abbreviated day names.  */
-	N_("Sun"),
-	N_("Mon"),
-	N_("Tue"),
-	N_("Wed"),
-	N_("Thu"),
-	N_("Fri"),
-	N_("Sat")
-};
-
-static const gchar *day_names[] = {
-/* i18n: full day names.  */
-	N_("Sunday"),
-	N_("Monday"),
-	N_("Tuesday"),
-	N_("Wednesday"),
-	N_("Thursday"),
-	N_("Friday"),
-	N_("Saturday")
-};
+static const gchar *month_names_initial[12];
+static const gchar *short_day_names[7];
+static const gchar *day_names[7];
 
 static gchar *time_tz_orig = NULL;
 
+/**
+ * mrp_time_compose:
+ * @year: the year
+ * @month: the month
+ * @day: the day
+ * @hour: the hour
+ * @minute: the minute
+ * @second: the second
+ * 
+ * Composes an #mrptime value from the separate components.
+ * 
+ * Return value: An #mrptime value.
+ **/
 mrptime
 mrp_time_compose (gint year,
 		  gint month,
@@ -126,6 +76,20 @@ mrp_time_compose (gint year,
 	return mrp_time_from_tm (&tm);
 }
 
+/**
+ * mrp_time_decompose:
+ * @t: an #mrptime value to decompose
+ * @year: location to store year, or %NULL
+ * @month: location to store month, or %NULL
+ * @day: location to store day, or %NULL
+ * @hour: location to store hour, or %NULL
+ * @minute: location to store minute, or %NULL
+ * @second: location to store second, or %NULL
+ * 
+ * Splits up an #mrptime value into its components.
+ * 
+ * Return value: %TRUE on success.
+ **/
 gboolean
 mrp_time_decompose (mrptime  t,
 		    gint    *year,
@@ -167,6 +131,12 @@ mrp_time_decompose (mrptime  t,
 	return TRUE;
 }	    
 
+/**
+ * mrp_time_debug_print:
+ * @t: an  #mrptime
+ * 
+ * Prints the time on stdout, for debugging purposes.
+ **/
 void
 mrp_time_debug_print (mrptime t)
 {
@@ -218,6 +188,14 @@ time_reset_tz (void)
 	}
 }
 
+/**
+ * mrp_time_from_tm:
+ * @tm: pointer to a struct tm time value
+ * 
+ * Converts a struct tm value to an #mrptime value.
+ * 
+ * Return value: #mrptime value.
+ **/
 mrptime
 mrp_time_from_tm (struct tm *tm)
 {
@@ -230,6 +208,13 @@ mrp_time_from_tm (struct tm *tm)
 	return t;
 }
 
+/**
+ * mrp_time_current_time:
+ * 
+ * Retrieves the current time as an #mrptime value.
+ *
+ * Return value: Current time.
+ **/
 mrptime
 mrp_time_current_time (void)
 {
@@ -244,6 +229,15 @@ mrp_time_current_time (void)
 	return t;
 }
 
+/**
+ * mrp_time_to_tm:
+ * @t: an #mrptime value
+ * 
+ * Converts @t to a struct tm value.
+ * 
+ * Return value: struct tm time, which is static data and should not be
+ * modified or freed..
+ **/
 struct tm *
 mrp_time_to_tm (mrptime t)
 {
@@ -254,6 +248,15 @@ mrp_time_to_tm (mrptime t)
 	return gmtime (&tt);
 }
 
+/**
+ * mrp_time_from_string:
+ * @str: a string with a time, ISO8601 format
+ * @err: Location to store error, or %NULL
+ * 
+ * Parses an ISO8601 time string and converts it to an #mrptime.
+ * 
+ * Return value: Converted time value.
+ **/
 mrptime
 mrp_time_from_string (const gchar  *str,
 		      GError      **err)
@@ -333,6 +336,14 @@ mrp_time_from_string (const gchar  *str,
 				 second);
 }
 
+/**
+ * mrp_time_to_string:
+ * @t: an #mrptime time
+ * 
+ * Converts a time value to an ISO8601 string.
+ * 
+ * Return value: Allocated string that needs to be freed.
+ **/
 gchar *
 mrp_time_to_string (mrptime t)
 {
@@ -349,6 +360,14 @@ mrp_time_to_string (mrptime t)
 				tm->tm_sec);
 }
 
+/**
+ * mrp_time_align_day:
+ * @t: an #mrptime value
+ * 
+ * Aligns a time value to the start of the day.
+ * 
+ * Return value: Aligned value.
+ **/
 mrptime
 mrp_time_align_day (mrptime t)
 {
@@ -362,7 +381,14 @@ mrp_time_align_day (mrptime t)
 	return mrp_time_from_tm (tm);
 }
 
-/* Range 0-6, Sunday is 0. */ 
+/**
+ * mrp_time_day_of_week:
+ * @t: an #mrptime value
+ * 
+ * Retrieves the day of week of the specified time.
+ * 
+ * Return value: The day of week, in the range 0 to6, where Sunday is 0.
+ **/
 gint
 mrp_time_day_of_week (mrptime t)
 {
@@ -373,6 +399,14 @@ mrp_time_day_of_week (mrptime t)
 	return tm->tm_wday;
 }
 
+/**
+ * mrp_time_week_number:
+ * @t: an #mrptime value
+ * 
+ * Retrieves the week number of the specified time.
+ * 
+ * Return value: ISO standard week number.
+ **/
 gint
 mrp_time_week_number (mrptime t)
 {
@@ -386,6 +420,17 @@ mrp_time_week_number (mrptime t)
 	return atoi (str);
 }
 
+/**
+ * mrp_param_spec_time:
+ * @name: name of the property
+ * @nick: nick for the propery
+ * @blurb: blurb for the property
+ * @flags: flags
+ * 
+ * Convenience function for creating a #GParamSpec carrying an #mrptime value.
+ * 
+ * Return value: Newly created #GparamSpec.
+ **/
 GParamSpec *
 mrp_param_spec_time (const gchar *name,
 		     const gchar *nick,
@@ -496,6 +541,14 @@ static const gchar *ms_month_names[] = {
 	"Dec"
 };
 
+/**
+ * mrp_time_from_msdate_string:
+ * @str: Date/time string formatted as in MS Project
+ * 
+ * Converts an MS date string to an #mrptime value.
+ * 
+ * Return value: Converted time value.
+ **/
 mrptime
 mrp_time_from_msdate_string (const gchar *str)
 {
@@ -602,6 +655,14 @@ mrp_time_from_msdate_string (const gchar *str)
 	return MRP_TIME_INVALID;
 }
 
+/**
+ * mrp_time_day_name:
+ * @t: an #mrptime value
+ * 
+ * Retrieves the name of the day of the specified time. 
+ * 
+ * Return value: The day name, which is static data.
+ **/
 const gchar *
 mrp_time_day_name (mrptime t)
 {
@@ -614,6 +675,14 @@ mrp_time_day_name (mrptime t)
 	return short_day_names[dow];
 }
 
+/**
+ * mrp_time_month_name:
+ * @t: an #mrptime value
+ * 
+ * Retrieves the name of the month of the specified time.
+ * 
+ * Return value: The month name, which is static data.
+ **/
 const gchar *
 mrp_time_month_name (mrptime t)
 {
@@ -626,6 +695,14 @@ mrp_time_month_name (mrptime t)
 	return short_month_names[tm->tm_mon];
 }
 
+/**
+ * mrp_time_month_name_initial:
+ * @t: an #mrptime value
+ * 
+ * Retrieves the initial letter for the month of the specified time.
+ * 
+ * Return value: The initial, which is static data.
+ **/
 const gchar *
 mrp_time_month_name_initial (mrptime t)
 {
@@ -638,43 +715,34 @@ mrp_time_month_name_initial (mrptime t)
 	return month_names_initial[tm->tm_mon];
 }
 
+/**
+ * imrp_time_init:
+ * 
+ * Initializes the time functions. Must be called before using any mrp_
+ * functions.
+ **/
 void
 imrp_time_init (void)
 {
-	gint   i, len;
-	gchar *p;
+	gint i;
 	
-	/* Pre-translate month and day names. */
-	len = G_N_ELEMENTS (short_month_names);
-	for (i = 0; i < len; i++) {
-		short_month_names[i] = _(short_month_names[i]);
+	/* Get month and day names. */
+	
+	for (i = 0; i < 12; i++) {
+		gunichar c;
+		
+		short_month_names[i] = g_strdup (nl_langinfo (ABMON_1 + i));
+		month_names[i] = g_strdup (nl_langinfo (MON_1 + i));
+		
+		c = g_utf8_get_char (month_names[i]);
+		month_names_initial[i] = g_malloc0 (7);
+		g_unichar_to_utf8 (c, (char *)month_names_initial[i]);
+		
 	}
 
-	len = G_N_ELEMENTS (month_names);
-	for (i = 0; i < len; i++) {
-		month_names[i] = _(month_names[i]);
-	}
-	
-	len = G_N_ELEMENTS (month_names_initial);
-	for (i = 0; i < len; i++) {
-		/* We'll leak those string, but only once per app. */
-		month_names_initial[i] = g_strdup (_(month_names_initial[i]));
-
-		/* Strip out the " x". */
-		p = g_strrstr (month_names_initial[i], " ");
-		if (p) {
-			*p = '\0';
-		}
-	}
-	
-	len = G_N_ELEMENTS (short_day_names);
-	for (i = 0; i < len; i++) {
-		short_day_names[i] = _(short_day_names[i]);
-	}
-
-	len = G_N_ELEMENTS (day_names);
-	for (i = 0; i < len; i++) {
-		day_names[i] = _(day_names[i]);
+	for (i = 0; i < 7; i++) {
+		short_day_names[i] = g_strdup (nl_langinfo (ABDAY_1 + i));
+		day_names[i] = g_strdup (nl_langinfo (DAY_1 + i));
 	}
 }
 
@@ -953,6 +1021,38 @@ time_format_helper (const gchar *format,
 	return len + 1;
 }
 
+/**
+ * mrp_time_format:
+ * @format: format string 
+ * @t: an #mrptime value
+ * 
+ * Formats a string with time values. The following format codes are allowed:
+ * <informalexample><programlisting>
+ * %a     The abbreviated weekday name (Mon, Tue, ...)
+ * %A     The full weekday name (Monday, Tuesday, ...)
+ * %b     The abbreviated month name (Jan, Feb, ...)
+ * %B     The full month name (January, February, ...)
+ * %d     The day of the month (01 - 31).
+ * %e     The day of the month (1 - 31).
+ * %H     The hour using a 24-hour clock (00 - 23).
+ * %I     The hour using a 12-hour clock (01 - 12).
+ * %j     The day of the year (001 - 366).
+ * %k     The hour using a 24-hour clock (0 to 23).
+ * %l     The hour using a 12-hour clock (1 - 12).
+ * %m     The month number (01 to 12).
+ * %M     The minute (00 - 59).
+ * %p     Either 'AM' or 'PM' according  to the given time value.
+ * %P     Like %p but in lowercase.
+ * %R     The time in 24 hour notation (%H:%M).
+ * %S     The second (00 - 61).
+ * %U     The week number, (1 - 53), starting with the first Sunday as the first day of week 1.
+ * %W     The week number, (1 - 53), starting with the first Monday as the first day of week 1.
+ * %y     The year without a century (range 00 to 99).
+ * %Y     The year including the century.
+ * </programlisting></informalexample>
+ *
+ * Return value: Newly created string that needs to be freed.
+ **/
 gchar *
 mrp_time_format (const gchar *format, mrptime t)
 {
